@@ -1,6 +1,6 @@
 /***************************************************************************
     Copyright 2014 Andreas Xavier
-    Copyright 2014 Inge Wallin
+    Copyright 2014 Inge Wallin <inge@lysator.liu.se>
  ***************************************************************************/
 
 /***************************************************************************
@@ -12,6 +12,8 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifndef GRADEREFERENCEWIDGET_H
+#define GRADEREFERENCEWIDGET_H
 
 #include <QWidget>
 
@@ -19,9 +21,11 @@
 class GradeReferenceWidget : public QWidget
 {
 public:
-    GradeReferenceWidget(QWidget *parent = 0);
+    explicit GradeReferenceWidget(QWidget *parent = 0);
 
 protected:
     void paintEvent(QPaintEvent *) Q_DECL_OVERRIDE;
 
 };
+
+#endif
